/* keyboard.h
 *
 * Copyright (C) 2017 Timothy Richard Musson
 *
 * Email: Tim Musson <trmusson@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */


#ifndef HAVE_KEYBOARD_H
#define HAVE_KEYBOARD_H

#include "config.h"
#include "profile.h"


#define EMU_KEY_RUB_OUT           -1
#define EMU_KEY_UP_ARROW          -2
#define EMU_KEY_LINE_FEED         EMU_KEY_UP_ARROW
#define EMU_KEY_RETURN            -3
#define EMU_KEY_CTRL              -4
#define EMU_KEY_SHIFT_LOCK        -5
#define EMU_KEY_SHIFT_LT          -6
#define EMU_KEY_SHIFT_RT          -7
#define EMU_KEY_SPACE             -8
#define EMU_KEY_ESC               -9
#define EMU_KEY_REPEAT            -10
#define EMU_KEY_STEP              -97
#define EMU_KEY_STEP_TOGGLE       -98
#define EMU_KEY_BREAK             -99
#define EMU_KEY_FULLSCREEN_TOGGLE -100


typedef enum {

	KEYBOARD_TYPE_STDIO,
	KEYBOARD_TYPE_NCURSES,
	KEYBOARD_TYPE_OSI542,
	KEYBOARD_TYPE_OSI600,
	KEYBOARD_TYPE_UK101,
	KEYBOARD_TYPE_UK101_US

} KeyboardType;


typedef struct _Keyboard Keyboard;


Keyboard* keyboard_new (Profile *p);
void      keyboard_free (Keyboard *k);

void      keyboard_key_press (Keyboard *k, int id);
void      keyboard_key_release (Keyboard *k, int id);

xbool_t    keyboard_get_reset (Keyboard *k);
void      keyboard_set_reset (Keyboard *k, xbool_t reset);

xbool_t    keyboard_get_stepping (Keyboard *k);
void      keyboard_set_stepping (Keyboard *k, xbool_t reset);

xbool_t    keyboard_get_step_now (Keyboard *k);
void      keyboard_set_step_now (Keyboard *k, xbool_t step_now);

xbool_t    keyboard_get_fullscreen_toggle (Keyboard *k);
void      keyboard_set_fullscreen_toggle (Keyboard *k, xbool_t toggle);


#ifdef ENABLE_SDL
void      keyboard_event_sdl (Keyboard *keyboard, int key, xbool_t down);
#endif

#ifdef ENABLE_NCURSES
void      keyboard_event_ncurses (Keyboard *keyboard, int key);
#endif


#endif

